# Changelog

## 1.0.1 (2025-11-05)

Full Changelog: [v0.0.1...v1.0.1](https://github.com/with-ours/ingest-sdk-python/compare/v0.0.1...v1.0.1)

### Features

* **api:** manual updates ([bb8c874](https://github.com/with-ours/ingest-sdk-python/commit/bb8c8740c8db117eea1397087a1c6caf84dc9f4f))
* **api:** manual updates ([2fb7a18](https://github.com/with-ours/ingest-sdk-python/commit/2fb7a189d3d85379b026eda316d0941895bf523e))


### Chores

* configure new SDK language ([57f5f26](https://github.com/with-ours/ingest-sdk-python/commit/57f5f26caf7d784f70bf2aa313030c64c4404e5a))
* **internal:** grammar fix (it's -&gt; its) ([fcb2e5a](https://github.com/with-ours/ingest-sdk-python/commit/fcb2e5a28fc12b5d828409f474936d5300e5abf4))
* update SDK settings ([23d204c](https://github.com/with-ours/ingest-sdk-python/commit/23d204c23a68376a0340d1fa6dc160477fe9dd11))
* update SDK settings ([f53800e](https://github.com/with-ours/ingest-sdk-python/commit/f53800e088f0068679c32bd7656dc75e74b9a727))
